@@ -283,6 +283,7 @@ module Aws
             'BCMPricingCalculator' => 'bcm-pricing-calculator',
             'Backup' => 'backup',
             'BackupGateway' => 'backup-gateway',
+            'BackupSearch' => 'backup-search',
             'Batch' => 'batch',
             'Bedrock' => 'bedrock',
             'BedrockAgent' => 'bedrock-agent',
@@ -385,13 +386,13 @@ module Aws
             'EMRServerless' => 'emr-serverless',
             'ElastiCache' => 'elasticache',
             'ElasticBeanstalk' => 'elasticbeanstalk',
-            'ElasticInference' => 'api.elastic-inference',
             'ElasticLoadBalancing' => 'elasticloadbalancing',
             'ElasticLoadBalancingV2' => 'elasticloadbalancing',
             'ElasticTranscoder' => 'elastictranscoder',
             'ElasticsearchService' => 'es',
             'EntityResolution' => 'entityresolution',
             'EventBridge' => 'events',
+            'Evs' => 'evs',
             'FIS' => 'fis',
             'FMS' => 'fms',
             'FSx' => 'fsx',
@@ -403,6 +404,7 @@ module Aws
             'FraudDetector' => 'frauddetector',
             'FreeTier' => 'freetier',
             'GameLift' => 'gamelift',
+            'GameLiftStreams' => 'gameliftstreams',
             'GeoMaps' => 'geo-maps',
             'GeoPlaces' => 'geo-places',
             'GeoRoutes' => 'geo-routes',
@@ -428,8 +430,6 @@ module Aws
             'InternetMonitor' => 'internetmonitor',
             'Invoicing' => 'invoicing',
             'IoT' => 'iot',
-            'IoT1ClickDevicesService' => 'devices.iot1click',
-            'IoT1ClickProjects' => 'projects.iot1click',
             'IoTAnalytics' => 'iotanalytics',
             'IoTDeviceAdvisor' => 'api.iotdeviceadvisor',
             'IoTEvents' => 'iotevents',
@@ -437,6 +437,7 @@ module Aws
             'IoTFleetHub' => 'api.fleethub.iot',
             'IoTFleetWise' => 'iotfleetwise',
             'IoTJobsDataPlane' => 'data.jobs.iot',
+            'IoTManagedIntegrations' => 'api.iotmanagedintegrations',
             'IoTSecureTunneling' => 'api.tunneling.iot',
             'IoTSiteWise' => 'iotsitewise',
             'IoTThingsGraph' => 'iotthingsgraph',
@@ -543,7 +544,6 @@ module Aws
             'Pipes' => 'pipes',
             'Polly' => 'polly',
             'Pricing' => 'api.pricing',
-            'PrivateNetworks' => 'private-networks',
             'PrometheusService' => 'aps',
             'Proton' => 'proton',
             'QApps' => 'data.qapps',
@@ -585,6 +585,7 @@ module Aws
             'SQS' => 'sqs',
             'SSM' => 'ssm',
             'SSMContacts' => 'ssm-contacts',
+            'SSMGuiConnect' => 'ssm-guiconnect',
             'SSMIncidents' => 'ssm-incidents',
             'SSMQuickSetup' => 'ssm-quicksetup',
             'SSO' => 'portal.sso',
